@@ -329,7 +329,7 @@ def _upload_file(request):
 
             # HANDLE UPLOAD
             uploadedfile = default_storage.save(file_path, filedata)
-            if default_storage.exists(file_path):
+            if default_storage.exists(file_path) and file_path != uploadedfile:
                 default_storage.move(smart_text(uploadedfile), smart_text(file_path), allow_overwrite=True)
 
             # POST UPLOAD SIGNAL
